@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# $Id: contentsme.py 3866 2007-01-06 16:05:25Z rogerb $
+# $Id: contentsme.py 4547 2008-01-05 07:00:04Z djpham $
 
 import HTMLParser
 import sys
@@ -17,6 +17,12 @@ class HHCParser(HTMLParser.HTMLParser):
     def handle_endtag(self, tag):
         getattr(self, "handle_end_"+tag)()
 
+    def handle_end_body(self):
+        pass
+
+    def handle_end_html(self):
+        pass
+
     def handle_start_html(self, attrs):
         pass
 
