@@ -41,10 +41,16 @@
    <img align=center height="30" width="30" src=\"CONCAT(file,.png)\" BORDER=0 ALT="">
 
 #define SCREENSHOT(file, description) \
-   <img align=center src=\"CONCAT(file,.png)\" BORDER=0 ALT=\"description\">
+   <p align="center" class="screenshot"><img align=center src=\"file\" BORDER=0 ALT=\"description\"></p>
+
+#define IMAGE(file,description) \
+   <p align="center" class="screenshot"><img align=center src=\"file\" BORDER=0 ALT=\"description\"></p>
 
 #define TEXTLINK(file,title,desc) \
    <b>desc:</b> <a href=\"file\">title</a>&nbsp;&nbsp;
 
+#define TABLE <table cellspacing=5 cellpadding=5>
+#define TABLE_GRID <table cellspacing=5 cellpadding=5 border=1 class="grid">
+
 <h1>_HELP_TITLE</h1>
 
