@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: phone_features.py 4158 2007-03-19 21:38:05Z djpham $
+### $Id: phone_features.py 4672 2008-08-11 21:22:19Z djpham $
 
 """ Generate Phone Features from source code """
 
@@ -62,7 +62,11 @@ def generate_phone_features():
                     d[f]['w']=True
         for f in misc_features:
             d[f]={ 'x': req_attrs[f](module) }
-        r[model]=d
+        if hasattr(module.Phone, 'helpid') and module.Phone.helpid:
+            _model_name='<a href="%s">%s</a>'%( module.Phone.helpid, model)
+        else:
+            _model_name=model
+        r[_model_name]=d
     return r
 
 def html_results(r):
