@@ -5,9 +5,10 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: bphtml.py 4230 2007-05-10 22:52:21Z djpham $
+### $Id: bphtml.py 4380 2007-08-29 00:17:07Z djpham $
 
 # Standard modules
+from __future__ import with_statement
 import copy
 import webbrowser
 import re
@@ -316,28 +317,26 @@ class HtmlEasyPrinting:
         self.parent=parent
 
     def PrinterSetup(self):
-        printerDialog = wx.PrintDialog(self.parent)
-        if self.printData.Ok():
-            printerDialog.GetPrintDialogData().SetPrintData(self.printData.copy())
-        printerDialog.GetPrintDialogData().SetSetupDialog(True)
-        if printerDialog.ShowModal()==wx.ID_OK:
-            self.printData = PrintData(printerDialog.GetPrintDialogData().GetPrintData())
-            self._printdatatoconfig(self.printData)
-        printerDialog.Destroy()
+        with guihelper.WXDialogWrapper(wx.PrintDialog(self.parent)) as printerDialog:
+            if self.printData.Ok():
+                printerDialog.GetPrintDialogData().SetPrintData(self.printData.copy())
+            printerDialog.GetPrintDialogData().SetSetupDialog(True)
+            if printerDialog.ShowModal()==wx.ID_OK:
+                self.printData = PrintData(printerDialog.GetPrintDialogData().GetPrintData())
+                self._printdatatoconfig(self.printData)
 
     def PageSetup(self):
         psdd=wx.PageSetupDialogData()
         if self.printData.Ok():
             psdd.SetPrintData(self.printData.copy())
         self._configtopagesetupdata(psdd)
-        pageDialog=wx.PageSetupDialog(self.parent, psdd)
-        if pageDialog.ShowModal()==wx.ID_OK and \
-           pageDialog.GetPageSetupData().Ok() and \
-           pageDialog.GetPageSetupData().GetPrintData().Ok():
-            self.printData=PrintData(pageDialog.GetPageSetupData().GetPrintData())
-            self._printdatatoconfig(self.printData)
-            self._pagesetupdatatoconfig(pageDialog.GetPageSetupData())
-        pageDialog.Destroy()
+        with guihelper.WXDialogWrapper(wx.PageSetupDialog(self.parent, psdd)) as pageDialog:
+            if pageDialog.ShowModal()==wx.ID_OK and \
+               pageDialog.GetPageSetupData().Ok() and \
+               pageDialog.GetPageSetupData().GetPrintData().Ok():
+                self.printData=PrintData(pageDialog.GetPageSetupData().GetPrintData())
+                self._printdatatoconfig(self.printData)
+                self._pagesetupdatatoconfig(pageDialog.GetPageSetupData())
 
     def PreviewText(self, htmltext, basepath="", scale=1.0):
         printout1=self._getprintout(htmltext, basepath, scale)
@@ -368,9 +367,9 @@ class HtmlEasyPrinting:
         if not pdd.GetPrintData().Orientation:
             pdd.GetPrintData().SetOrientation(wx.PORTRAIT)
         printer=wx.Printer(pdd)
-        printout=self._getprintout(htmltext, basepath, scale)
-        printer.Print(self.parent, printout)
-        printout.Destroy()
+        with guihelper.WXDialogWrapper(self._getprintout(htmltext, basepath, scale)) \
+             as printout:
+            printer.Print(self.parent, printout)
 
     def _getprintout(self, htmltext, basepath, scale):
         printout=wx.html.HtmlPrintout()
@@ -456,7 +455,8 @@ class Renderer:
     _bmp=None
     _hdc=None
 
-    def getbestsize(html, basepath, font, size):
+    @classmethod
+    def getbestsize(_, html, basepath, font, size):
         if Renderer._bmp is None:
             Renderer._bmp=wx.EmptyBitmap(1,1)
             Renderer._mdc=wx.MemoryDC()
@@ -469,10 +469,7 @@ class Renderer:
             Renderer._hdc.SetFonts(font, "", [int(x*size) for x in _scales])
         Renderer._hdc.SetHtmlText(html, basepath)
         Renderer._hdc.Render(0, 0, (), 0, False)
-        return (Renderer._mdc.MaxX(), Renderer._mdc.MaxY())
-
-    getbestsize=staticmethod(getbestsize)
-        
+        return (Renderer._mdc.MaxX(), Renderer._mdc.MaxY())        
 
 def getbestsize(dc, html, basepath="", font="", size=10):
     return Renderer.getbestsize(html, basepath, font, size)
