@@ -7,7 +7,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: calendarcontrol.py 3949 2007-01-30 23:17:40Z djpham $
+### $Id: calendarcontrol.py 4407 2007-09-25 20:39:48Z djpham $
 
 """A calendar control that shows several weeks in one go
 
@@ -374,7 +374,7 @@ class CalendarCell(wx.PyWindow):
     def OnLeaveWindow(self, _):
         self._timer.Stop()
     def OnTimer(self, _):
-        if not self.entries:
+        if not self.entries or wx.GetApp().critical.isSet():
             return
         _rect=self.GetRect()
         _x,_y=self.GetParent().ClientToScreen(_rect[:2])
