@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: calendarentryeditor.py 4397 2007-09-13 01:26:23Z djpham $
+### $Id: calendarentryeditor.py 4708 2008-09-06 04:10:44Z djpham $
 
 from __future__ import with_statement
 import calendar
@@ -1092,7 +1092,7 @@ class DVIntControl(wx.lib.intctrl.IntCtrl):
     def SetValue(self, v):
         if v is None:
             v=-1
-        wx.lib.intctrl.IntCtrl.SetValue(self,v)
+        wx.lib.intctrl.IntCtrl.SetValue(self,int(v))
         
 #------------------------------------------------------------------------------    
 class DVTextControl(wx.TextCtrl):
