@@ -5,16 +5,17 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: call_history_export.py 3460 2006-07-08 23:55:09Z djpham $
+### $Id: call_history_export.py 4377 2007-08-27 04:58:33Z djpham $
 
 "Deals with Call History import/export stuff"
 # System Module
-
+from __future__ import with_statement
 # wxPython modules
 import wx
 
 # BitPim Modules
 import bptime
+import guihelper
 import phonenumber
 
 #------------------------------------------------------------------------------
@@ -63,11 +64,11 @@ class ExportCallHistoryDialog(wx.Dialog):
         return hbs
 
     def OnBrowse(self, _):
-        dlg=wx.FileDialog(self, defaultFile=self.filenamectrl.GetValue(),
-                          wildcard="CSV files (*.csv)|*.csv", style=wx.SAVE|wx.CHANGE_DIR)
-        if dlg.ShowModal()==wx.ID_OK:
-            self.filenamectrl.SetValue(dlg.GetPath())
-        dlg.Destroy()
+        with guihelper.WXDialogWrapper(wx.FileDialog(self, defaultFile=self.filenamectrl.GetValue(),
+                                                     wildcard="CSV files (*.csv)|*.csv", style=wx.SAVE|wx.CHANGE_DIR),
+                                       True) as (dlg, retcode):
+            if retcode==wx.ID_OK:
+                self.filenamectrl.SetValue(dlg.GetPath())
 
     def OnOk(self, _):
         # do export
@@ -77,10 +78,8 @@ class ExportCallHistoryDialog(wx.Dialog):
         except:
             _fp=None
         if _fp is None:
-            dlg=wx.MessageDialog(self, 'Failed to open file ['+filename+']',
-                             'Export Error')
-            dlg.ShowModal()
-            dlg.Destroy()
+            guihelper.MessageDialog(self, 'Failed to open file ['+filename+']',
+                                    'Export Error')
             self.EndModal(wx.ID_OK)
         if self.rows_all.GetValue():
             _data=self._data
