@@ -5,12 +5,15 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: common.py 4210 2007-05-03 21:42:01Z djpham $
+### $Id: common.py 4381 2007-08-29 00:19:51Z djpham $
 
 
 # Documentation
 """Various classes and functions that are used by GUI and command line versions of BitPim"""
 
+from __future__ import with_statement
+from contextlib import contextmanager
+
 # standard modules
 import string
 import cStringIO
@@ -249,15 +252,14 @@ def readversionedindexfile(filename, dict, versionhandlerfunc, currentversion):
 
 def writeversionindexfile(filename, dict, currentversion):
      assert currentversion>0
-     f=open(filename, "w")
-     for key in dict:
-          v=dict[key]
-          if isinstance(v, type({})):
-               f.write("result['%s']=%s\n" % (key, prettyprintdict(dict[key])))
-          else:
-               f.write("result['%s']=%s\n" % (key, `v`))
-     f.write("FILEVERSION=%d\n" % (currentversion,))
-     f.close()
+     with file(filename, 'w') as f:
+          for key in dict:
+               v=dict[key]
+               if isinstance(v, type({})):
+                    f.write("result['%s']=%s\n" % (key, prettyprintdict(dict[key])))
+               else:
+                    f.write("result['%s']=%s\n" % (key, `v`))
+          f.write("FILEVERSION=%d\n" % (currentversion,))
 
 def formatexceptioneh(*excinfo):
      print formatexception(excinfo)
@@ -430,17 +432,15 @@ def opentextfile(name):
      uses the codecs module instead to open the file instead with
      appropriate unicode decoding, else returns the file using standard
      open function"""
-     f=open(name, "rb")
-     start=f.read(_maxbomlen)
-     for bom,codec in _boms:
-          if start.startswith(bom):
-               f.close()
-               # some codecs don't do readline, so we have to vector via stringio
-               # many postings also claim that the BOM is returned as the first
-               # character but that hasn't been the case in my testing
-               return StringIO.StringIO(codecs.open(name, "r", codec).read())
-     f.close()
-     return open(name, "rtU")
+     with file(name, 'rb') as f:
+          start=f.read(_maxbomlen)
+          for bom,codec in _boms:
+               if start.startswith(bom):
+                    # some codecs don't do readline, so we have to vector via stringio
+                    # many postings also claim that the BOM is returned as the first
+                    # character but that hasn't been the case in my testing
+                    return StringIO.StringIO(codecs.open(name, "r", codec).read())
+     return file(name, "rtU")
 
 
 # don't you just love i18n
@@ -875,3 +875,16 @@ if sys.platform=='win32':
             return HIWORD (ms), LOWORD (ms), HIWORD (ls), LOWORD (ls)
         except:
             return None
+
+# simple generator that generates temp file name and del it afterward
+@contextmanager
+def usetempfile(ext):
+    _name=gettempfilename(ext)
+    try:
+        yield _name
+    finally:
+          try:
+              os.remove(_name)
+          except OSError:
+               # ignore if failed to del temp file
+               pass
