@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: common_calendar.py 4675 2008-08-12 21:52:12Z djpham $
+### $Id: common_calendar.py 4711 2008-09-27 21:04:32Z djpham $
 
 "Common stuff for the Calendar Import functions"
 
@@ -406,7 +406,7 @@ class FilterDialogBase(wx.Dialog):
             self.__ringtone.SetStringSelection(self.unnamed)
         value=data.get('vibrate', False);
         self.__vibrate.SetValue(value)
-        self.__alarm_value.SetValue(data.get('alarm_value', 0))
+        self.__alarm_value.SetValue(int(data.get('alarm_value', 0)))
         self.__set_cats(self.__cat_chkbox, self.__cats, data.get('categories', None))
 
     def get_base(self, r):
