@@ -7,7 +7,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: comscan.py 3932 2007-01-24 03:38:33Z djpham $
+### $Id: comscan.py 4368 2007-08-19 23:33:52Z djpham $
 
 
 """Detect and enumerate com(serial) ports
@@ -49,7 +49,9 @@ wW   driverdescription  string   some generic description of the driver
   L  driver             string   the driver name from /proc/devices (eg ttyS or ttyUSB)
 """
 
-version="$Revision: 3932 $"
+from __future__ import with_statement
+
+version="$Revision: 4368 $"
 
 import sys
 import os
@@ -359,15 +361,14 @@ def _comscanlinux(maxnum=9):
     drivers={}
 
     # get the list of char drivers from /proc/drivers
-    f=open("/proc/devices", "r")
-    f.readline()  # skip "Character devices:" header
-    for line in f.readlines():
-        line=line.split()
-        if len(line)!=2:
-            break # next section
-        major,driver=line
-        drivers[int(major)]=driver
-    f.close()
+    with file('/proc/devices', 'r') as f:
+        f.readline()  # skip "Character devices:" header
+        for line in f.readlines():
+            line=line.split()
+            if len(line)!=2:
+                break # next section
+            major,driver=line
+            drivers[int(major)]=driver
 
     # device nodes we have seen so we don't repeat them in listing
     devcache={}
@@ -394,9 +395,8 @@ def _comscanlinux(maxnum=9):
             res['description']=description+" ("+name+")"
             dev=os.stat(name).st_rdev
             try:
-                f=open(name, "rw")
-                f.close()
-                res['available']=True
+                with file(name, 'rw'):
+                    res['available']=True
             except:
                 res['available']=False
             # linux specific, and i think they do funky stuff on kernel 2.6
@@ -447,9 +447,8 @@ def _comscanmac():
            res['description']="Serial"+" ("+name+")"
            res['class']="serial"
        try:
-          f=open(name, "rw")
-          f.close()
-          res['available']=True
+            with file(name, 'rw'):
+                res['available']=True
        except:
           res['available']=False
        results[resultscount]=res
