@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: database.py 4370 2007-08-21 21:39:36Z djpham $
+### $Id: database.py 4697 2008-08-24 21:21:14Z djpham $
 
 """Interface to the database"""
 from __future__ import with_statement
@@ -653,7 +653,8 @@ class Database:
         schema=self.getcolumns(tablename)
         
         res=[]
-        for row in self.sqlmany("select * from %s where __rowid__=?" % (idquote(tablename),), [(int(r),) for r in rows.split(',') if len(r)]):
+        for row in self.sqlmany("select * from %s where __rowid__=?" %
+                                (idquote(tablename),), [(int(long(r)),) for r in rows.split(',') if len(r)]):
             record={}
             for colnum,name,type in schema:
                 if name.startswith("__") or type not in ("valueBLOB", "indirectBLOB", "indirectdictBLOB") or row[colnum] is None:
