@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: field_color.py 4693 2008-08-15 22:30:51Z djpham $
+### $Id: field_color.py 4775 2010-01-04 03:44:57Z djpham $
 
 """
 Code to handle setting colors for fields in various BitPim Editor Dialogs.
@@ -56,6 +56,7 @@ default_field_info={
         'storage': None,
         'secret': None,
         'ICE': None,
+        'im': None,
         },
     'calendar': {
         'description': None, 'location': None, 'allday': None,
@@ -101,7 +102,8 @@ def build_field_info(widget, name=None):
         _names=[]
     while _parent:
         if hasattr(_parent, 'color_field_name'):
-            _names.append(_parent.color_field_name)
+            if _parent.color_field_name not in _names:
+                _names.append(_parent.color_field_name)
         _parent=_parent.GetParent()
     _names.reverse()
     _dict=current_field_info
