@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: fileinfo.py 3608 2006-10-06 02:51:56Z djpham $
+### $Id: fileinfo.py 4731 2009-03-06 03:28:04Z hjelmn $
 
 "Returns information about files"
 
@@ -16,6 +16,7 @@ import common
 
 import midifile
 import wma_file
+import mp4_file
 
 class FailedFile:
     data=""
@@ -485,6 +486,10 @@ def getmp3fileinfo(filename):
     f=SafeFileWrapper(filename)
     return idaudio_zzMP3(f, True)
 
+def getmp4fileinfo(filename):
+    f=SafeFileWrapper(filename)
+    return idaudio_MP4(f)
+
 
 twooheightzeros="\x00"*208
 # want to make sure this gets evaluated last
@@ -868,6 +873,44 @@ def fmt_WMA(afi):
         res.append('Genre: %s'%afi.genre)
     return '\n'.join(res)
 
+# MPEG4 file support
+def idaudio_MP4(f):
+    "Identify a MP4 file"
+    try:
+        _mp4=mp4_file.MP4_File(f)
+        if not _mp4.valid:
+            return None
+        d={ 'format': 'MP4',
+            'mimetypes': ['audio/mpeg4'],
+            'duration': _mp4.duration,
+            'title':    _mp4.title,
+            'artist':   _mp4.artist,
+            'album':    _mp4.album,
+            'bitrate':  _mp4.bitrate,
+            'samplerate': _mp4.samplerate,
+            '_longdescription': fmt_MP4,
+            }
+        return AudioFileInfo(f, **d)
+    except:
+        if __debug__:
+            raise
+
+
+def fmt_MP4(afi):
+    res=[]
+    res.append("MPEG4")
+    res.append("%.1f Khz %0.1f seconds" % (afi.samplerate/1000.0, afi.duration,))
+    if afi.bitrate:
+        res.append(`afi.bitrate`+" kbps")
+    if afi.title:
+        res.append('Title: %s'%afi.title)
+    if afi.artist:
+        res.append('Artist: %s'%afi.artist)
+    if afi.album:
+        res.append('Album: %s'%afi.album)
+                                        
+    return "\n".join(res)
+
 audioids=[globals()[f] for f in dir() if f.startswith("idaudio_")]
 def identify_audiofile(filename):
     v=thefileinfocache.get(filename)
