@@ -7,7 +7,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: guiwidgets.py 4543 2008-01-04 23:44:24Z djpham $
+### $Id: guiwidgets.py 4675 2008-08-12 21:52:12Z djpham $
 
 """Most of the graphical user interface elements making up BitPim"""
 
@@ -226,9 +226,11 @@ class GetPhoneDialog(wx.Dialog):
                 else:
                     style=0
                 _rb=wx.RadioButton(self, -1, "", style=style)
-                if not self._dowesupport(source, self.actions[0][1], tval):
-                    _rb.Enable(False)
+                if self._dowesupport(source, self.actions[0][1], tval):
+                    wx.EVT_RADIOBUTTON(self, _rb.GetId(), self.OnOptionSelected)
+                else:
                     _rb.SetValue(False)
+                    _rb.Enable(False)
                 gs.Add(_rb, 0, wx.ALIGN_CENTRE)
                 self._widgets[source]['rb'][tval]=_rb
 
@@ -350,6 +352,17 @@ class GetPhoneDialog(wx.Dialog):
                    _w['cb'].exclusive:
                     _w['cb'].SetValue(False)
 
+    def OnOptionSelected(self, evt):
+        # User clicked on an option
+        # Turn on the row to which this option belongs
+        _rb=evt.GetEventObject()
+        for _w1 in self._widgets.values():
+            if _rb in _w1['rb'].values():
+                _w1['cb'].SetValue(True)
+                # and turn on the OK button
+                self.DoOkStatus()
+                return
+
     def DoOkStatus(self, evt=None):
         # ensure the OK button is in the right state
         if evt and evt.IsChecked():
