@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: ical_calendar.py 4396 2007-09-12 21:44:00Z djpham $
+### $Id: ical_calendar.py 4708 2008-09-06 04:10:44Z djpham $
 
 "Deals with iCalendar calendar import stuff"
 
@@ -219,11 +219,12 @@ class iCalendarImportData(parentclass):
         return _rep
 
     def _conv_exceptions(self, v, _):
+        r=[]
         try:
-            l=v['value'].split(',')
-            r=[]
-            for n in l:
-                r.append(bptime.BPTime(n).get())
+            _val=v if isinstance(v, (list, tuple)) else [v]
+            for _item in _val:
+                for n in _item['value'].split(','):
+                    r.append(bptime.BPTime(n).get())
             return r
         except:
             if __debug__:
@@ -343,6 +344,7 @@ class ExportDialog(ExportDialogParent):
             _params=('VALUE=DATE',)
             _res=out_line('DTSTART', _params,
                           _start.iso_str(no_time=True), None)
+            _end+=bptime.timedelta(days=1)
             _res+=out_line('DTEND', _params,
                            _end.iso_str(no_time=True), None)
         else:
@@ -356,10 +358,12 @@ class ExportDialog(ExportDialogParent):
         _end=bptime.BPTime(event.end)
         if event.allday:
             # all day event, can only handle sameday allday event (for now)
-            _date_str=_start.iso_str(no_time=True)
             _params=('VALUE=DATE',)
-            _res=out_line('DTSTART', _params, _date_str, None)
-            _res+=out_line('DTEND', _params, _date_str, None)
+            _res=out_line('DTSTART', _params,
+                          _start.iso_str(no_time=True), None)
+            _end+=bptime.timedelta(days=1)
+            _res+=out_line('DTEND', _params,
+                           _end.iso_str(no_time=True), None)
         else:
             # can only handle 24hr-long event (for now)
             _new_end=_start+(_end-_start).seconds
