@@ -7,12 +7,13 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: imp_cal_preset.py 4195 2007-04-10 22:52:15Z djpham $
+### $Id: imp_cal_preset.py 4380 2007-08-29 00:17:07Z djpham $
 
 """ Handle Import Calendar Preset feature
 """
 
 # System
+from __future__ import with_statement
 import calendar
 import copy
 import datetime
@@ -155,11 +156,11 @@ class PresetFilterPage(setphone_wizard.MyPage):
         return gs
 
     def _OnFilter(self, _):
-        dlg=FilterDialog(self, -1, 'Filtering Parameters', self._data)
-        if dlg.ShowModal()==wx.ID_OK:
-            self._data.update(dlg.get())
-            self._populate()
-        dlg.Destroy()
+        with guihelper.WXDialogWrapper(FilterDialog(self, -1, 'Filtering Parameters', self._data),
+                                       True) as (dlg, retcode):
+            if retcode==wx.ID_OK:
+                self._data.update(dlg.get())
+                self._populate()
 
     def _display(self, key, attr, fmt):
         # display the value field of this key
@@ -334,16 +335,15 @@ class ImportCalendarPresetDialog(wx.Dialog):
 
     def _preview_data(self):
         # Display a preview of data just imported
-        _dlg=CalendarPreviewDialog(self, self._import_data.get())
-        _ret_code=_dlg.ShowModal()
-        _dlg.Destroy()
-        if _ret_code==CalendarPreviewDialog.ID_REPLACE:
-            return wx.ID_OK
-        elif _ret_code==CalendarPreviewDialog.ID_ADD:
-            return self.ID_ADD
-        elif _ret_code==CalendarPreviewDialog.ID_MERGE:
-            return self.ID_MERGE
-        return wx.ID_CANCEL
+        with guihelper.WXDialogWrapper(CalendarPreviewDialog(self, self._import_data.get()),
+                                       True) as (_dlg, _ret_code):
+            if _ret_code==CalendarPreviewDialog.ID_REPLACE:
+                return wx.ID_OK
+            elif _ret_code==CalendarPreviewDialog.ID_ADD:
+                return self.ID_ADD
+            elif _ret_code==CalendarPreviewDialog.ID_MERGE:
+                return self.ID_MERGE
+            return wx.ID_CANCEL
 
     def _get_preset_thisweek(self):
         # return the dates of (today, Sat)
@@ -385,6 +385,7 @@ class ImportCalendarPresetDialog(wx.Dialog):
                                               '_get_preset_thismonth',
                                               '_get_preset_thisyear',
                                               '_get_preset_next7'][_preset_date])()
+    @guihelper.BusyWrapper
     def _OnRun(self, _):
         _idx=self._name_lb.GetSelection()
         if _idx==wx.NOT_FOUND:
@@ -399,15 +400,12 @@ class ImportCalendarPresetDialog(wx.Dialog):
         self._import_data=_info['data']()
         _source=_info['source']()
         _source.id=_entry['source_id']
-        wx.BeginBusyCursor()
-        _dlg=wx.ProgressDialog('Calendar Data Import',
-                               'Importing data, please wait ...',
-                               parent=self)
-        self._import_data.read(_source.get(), _dlg)
-        self._adjust_filter_dates(_entry)
-        self._import_data.set_filter(_entry)
-        _dlg.Destroy()
-        wx.EndBusyCursor()
+        with guihelper.WXDialogWrapper(wx.ProgressDialog('Calendar Data Import',
+                                                         'Importing data, please wait ...',
+                                                         parent=self)) as _dlg:
+            self._import_data.read(_source.get(), _dlg)
+            self._adjust_filter_dates(_entry)
+            self._import_data.set_filter(_entry)
         global IMP_OPTION_PREVIEW, IMP_OPTION_REPLACEALL, IMP_OPTION_ADD, IMP_OPTION_MERGE
         _option=_entry.get('option', IMP_OPTION_PREVIEW)
         if _option==IMP_OPTION_PREVIEW:
@@ -422,27 +420,27 @@ class ImportCalendarPresetDialog(wx.Dialog):
 
     def _OnNew(self, _):
         _entry=ImportCalendarEntry()
-        _wiz=ImportCalendarPresetWizard(self, _entry)
-        if _wiz.RunWizard():
-            _entry=_wiz.get()
-            self._data[_entry.id]=_entry
-            self._save_to_fs()
-            self._populate()
-        _wiz.Destroy()
+        with guihelper.WXDialogWrapper(ImportCalendarPresetWizard(self, _entry)) \
+             as _wiz:
+            if _wiz.RunWizard():
+                _entry=_wiz.get()
+                self._data[_entry.id]=_entry
+                self._save_to_fs()
+                self._populate()
     def _OnEdit(self, _):
         _idx=self._name_lb.GetSelection()
         if _idx==wx.NOT_FOUND:
             return
         _key=self._name_lb.GetClientData(_idx)
         _entry=self._data[_key].copy()
-        _wiz=ImportCalendarPresetWizard(self, _entry)
-        if _wiz.RunWizard():
-            _entry=ImportCalendarEntry(_wiz.get())
-            del self._data[_key]
-            self._data[_entry.id]=_entry
-            self._save_to_fs()
-            self._populate()
-        _wiz.Destroy()
+        with guihelper.WXDialogWrapper(ImportCalendarPresetWizard(self, _entry)) \
+             as _wiz:
+            if _wiz.RunWizard():
+                _entry=ImportCalendarEntry(_wiz.get())
+                del self._data[_key]
+                self._data[_entry.id]=_entry
+                self._save_to_fs()
+                self._populate()
     def _OnDel(self, _):
         _idx=self._name_lb.GetSelection()
         if _idx==wx.NOT_FOUND:
@@ -532,7 +530,7 @@ if __name__=="__main__":
     f=wx.Frame(None, title='imp_cal_preset')
     _data=ImportCalendarEntry()
     _data.id
-    w=ImportCalendarPresetWizard(f, _data)
-    print 'RunWizard:',w.RunWizard()
-    print 'Data:',w.get()
-    w.Destroy()
+    with guihelper.WXDialogWrapper(ImportCalendarPresetWizard(f, _data)) \
+         as w:
+        print 'RunWizard:',w.RunWizard()
+        print 'Data:',w.get()
