@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: memo.py 4378 2007-08-27 17:47:50Z djpham $
+### $Id: memo.py 4714 2008-10-21 01:50:47Z djpham $
 
 """
 Code to handle memo/note items
@@ -545,3 +545,13 @@ class MemoWidget(wx.Panel, widgets.BitPimWidget):
             pass
     def CanPrint(self):
         return True
+
+    def get_keys(self):
+        """Return the list of keys as being displayed"""
+        return [ self._item_list.GetClientData(x) \
+                 for x in range(self._item_list.GetCount()) ]
+
+    def get_selected_keys(self):
+        """Return the list of keys of selected items being displayed"""
+        return [ self._item_list.GetClientData(x) \
+                 for x in self._item_list.GetSelections() ]
