@@ -6,7 +6,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: __init__.py 4678 2008-08-13 23:46:56Z djpham $
+### $Id: __init__.py 4771 2010-01-02 06:08:36Z djpham $
 
 import helpids
 
@@ -49,7 +49,7 @@ _phonedata= { 'LG-AX8600': { 'module': 'com_lgax8600',
                             'brand': b_lg,
                             'helpid': helpids.ID_PHONE_LGC2000,
                             },
-              'LG-LX570 (Musiq)': { 'module': 'com_lglx570',
+              'LG-LX570 (Muziq)': { 'module': 'com_lglx570',
                                     'carrier': [c_sprint],
                                     'brand': b_lg,
                                     'helpid': helpids.ID_PHONE_LGLX570,
@@ -102,6 +102,11 @@ _phonedata= { 'LG-AX8600': { 'module': 'com_lgax8600',
                              'brand': b_lg,
                              'helpid': None,
                              },
+              'LG-VX5500': { 'module': 'com_lgvx5500',
+                             'carrier': [c_vzw],
+                             'brand': b_lg,
+                             'helpid': None,
+                             },
               'LG-LX5550': { 'module': 'com_lglx5550',
                              'carrier': [c_alltel],
                              'brand': b_lg,
@@ -194,6 +199,11 @@ _phonedata= { 'LG-AX8600': { 'module': 'com_lgax8600',
                              'brand': b_lg,
                              'helpid': None,
                              },
+              'LG-VX9600 (Versa)': { 'module': 'com_lgvx9600',
+                                     'carrier': [c_vzw],
+                                     'brand': b_lg,
+                                     'helpid': helpids.ID_PHONE_LGVX9600,
+                                    },
               'LG-VX9700 (Dare)': { 'module': 'com_lgvx9700',
                                     'carrier': [c_vzw],
                                     'brand': b_lg,
@@ -214,11 +224,26 @@ _phonedata= { 'LG-AX8600': { 'module': 'com_lgax8600',
                                      'brand': b_lg,
                                      'helpid': helpids.ID_PHONE_LGVX9100,
                                      },
+              'LG-VX9200 (enV 3)': { 'module': 'com_lgvx9200',
+                                     'carrier': [c_vzw],
+                                     'brand': b_lg,
+                                     'helpid': helpids.ID_PHONE_LGVX9200,
+                                     },
+              'LG-CX9200 (Keybo 2)': { 'module': 'com_lgcx9200',
+                                     'carrier': [c_telus],
+                                     'brand': b_lg,
+                                     'helpid': helpids.ID_PHONE_LGVX9200,
+                                     },
               'LG-VX10000 (Voyager)': { 'module': 'com_lgvx10000',
                                         'carrier': [c_vzw],
                                         'brand': b_lg,
                                         'helpid': helpids.ID_PHONE_LGVX10000,
                                         },
+              'LG-VX11000 (enV Touch)': { 'module': 'com_lgvx11000',
+                                        'carrier': [c_vzw],
+                                        'brand': b_lg,
+                                        'helpid': helpids.ID_PHONE_LGVX11000,
+                                        },
               'LG-VI125': { 'module': 'com_lgvi125',
                             'carrier': [c_sprint],
                             'brand': b_lg,
@@ -456,6 +481,11 @@ _phonedata= { 'LG-AX8600': { 'module': 'com_lgax8600',
                             'carrier': [c_vzw],
                             'helpid': helpids.ID_PHONE_SAMSUNGSCHU740,
                             },
+              'SCH-U750 (Alias 2)': { 'module': 'com_samsungschu750',
+                            'brand': b_samsung,
+                            'carrier': [c_vzw],
+                            'helpid': helpids.ID_PHONE_SAMSUNGSCHU750,
+                            },
               'SK6100' : { 'module': 'com_sk6100',
                            'brand': b_sk,
                            'carrier': [c_pelephone],
@@ -471,6 +501,11 @@ _phonedata= { 'LG-AX8600': { 'module': 'com_lgax8600',
                            'brand': b_sanyo,
                            'helpid': helpids.ID_PHONE_SANYOOTHERS,
                            },
+              'V3m (Sprint)': { 'module': 'com_motov3m_sprint',
+                                'brand': b_moto,
+                                'carrier': [c_sprint],
+                                'helpid': helpids.ID_PHONE_MOTOV3M,
+                                },
               'LG-VI5225': { 'module': 'com_lgvi5225',
                              'carrier': [c_sti],
                              'brand': b_lg,
