@@ -6,7 +6,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_lglg8100.py 3918 2007-01-19 05:15:12Z djpham $
+### $Id: com_lglg8100.py 4303 2007-07-13 20:46:53Z djpham $
 
 """Communicate with the LG VX5200 cell phone
 
@@ -121,6 +121,9 @@ class Phone(com_lgvx8100.Phone):
         com_lgvx4400.Phone.__init__(self,logtarget,commport)
         self.mode=self.MODENONE
 
+    def __del__(self):
+        pass
+
     def getcalendar(self,result):
         res={}
         # Read exceptions file first
