@@ -5,9 +5,9 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_lglx570.py 4678 2008-08-13 23:46:56Z djpham $
+### $Id: com_lglx570.py 4695 2008-08-20 22:29:12Z djpham $
 
-"""Communicate with the LG LX570 (Musiq) cell phone"""
+"""Communicate with the LG LX570 (Muziq) cell phone"""
 
 import common
 import com_brew
@@ -21,7 +21,7 @@ import sms
 #-------------------------------------------------------------------------------
 parentphone=com_lgvx4400.Phone
 class Phone(com_brew.RealBrewProtocol2, parentphone):
-    "Talk to the LG LX570 (Musiq) cell phone"
+    "Talk to the LG LX570 (Muziq) cell phone"
 
     desc="LG-LX570"
     helpid=helpids.ID_PHONE_LGLX570
