@@ -7,7 +7,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_lgtm520.py 3037 2006-04-03 00:30:28Z rogerb $
+### $Id: com_lgtm520.py 4543 2008-01-04 23:44:24Z djpham $
 
 "Talk to the LG TM520/VX10 cell phone"
 
@@ -577,12 +577,6 @@ class Profile(com_phone.Profile):
         ('ringtone', 'write', 'OVERWRITE'),
         )
 
-    def SyncQuery(self, source, action, type):
-        if (source, action, type) in self._supportedsyncs or \
-           (source, action, None) in self._supportedsyncs:
-            return True
-        return False
-
     def convertphonebooktophone(self, helper, data):
 	"Converts the data to what will be used by the phone"
 
