@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_lgvi125.py 3460 2006-07-08 23:55:09Z djpham $
+### $Id: com_lgvi125.py 4365 2007-08-17 21:11:59Z djpham $
 
 """Communicate with the LG VI125 cell phone"""
 
@@ -788,7 +788,8 @@ class Phone(com_phone.Phone,com_brew.BrewProtocol,com_lg.LGPhonebook,com_lg.LGIn
             if s:
                 res['esn']=self.get_esn(s)
 
-    def detectphone(coms, likely_ports, res, _module, _log):
+    @classmethod
+    def detectphone(_, coms, likely_ports, res, _module, _log):
         if not likely_ports:
             # cannot detect any likely ports
             return None
@@ -815,8 +816,6 @@ class Phone(com_phone.Phone,com_brew.BrewProtocol,com_lg.LGPhonebook,com_lg.LGIn
                 if __debug__:
                     raise
     
-    detectphone=staticmethod(detectphone)
-
     # Calendar stuff------------------------------------------------------------
     def getcalendar(self,result):
         # Read exceptions file first
