@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_lgvx4400.py 4395 2007-09-11 21:11:45Z djpham $
+### $Id: com_lgvx4400.py 4636 2008-07-21 03:25:38Z djpham $
 
 """Communicate with the LG VX4400 cell phone"""
 
@@ -202,7 +202,7 @@ class Phone(com_phone.Phone,com_brew.BrewProtocol,com_lg.LGPhonebook,com_lg.LGIn
     def _getoutboxmessage(self, sf):
         entry=sms.SMSEntry()
         entry.folder=entry.Folder_Sent
-        entry.datetime="%d%02d%02dT%02d%02d00" % ((sf.timesent))
+        entry.datetime="%d%02d%02dT%02d%02d00" % sf.timesent[:5]
         # add all the recipients
         for r in sf.recipients:
             if r.number:
