@@ -7,7 +7,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_lgvx8600.py 3974 2007-02-10 03:54:37Z djpham $
+### $Id: com_lgvx8600.py 4305 2007-07-16 04:05:25Z djpham $
 
 """
 Communicate with the LG VX8600 cell phone, which I was told is VERY similar to
@@ -30,6 +30,21 @@ class Phone(parentphone):
 
     my_model='VX8600'
 
+    def setDMversion(self):
+        _fw_version=self.get_firmware_version()[-1]
+        # T86VZV03 uses DMv5
+        self._DMv5=self.my_model=='VX8600' and _fw_version>'2'
+        if self._DMv5:
+            # takes about 30 seconds for T86VZV03 to kick out of DM
+            self._timeout = 30
+
+    # Fundamentals:
+    #  - get_esn             - same as LG VX-8300
+    #  - getgroups           - same as LG VX-8100
+    #  - getwallpaperindices - LGUncountedIndexedMedia
+    #  - getrintoneindices   - LGUncountedIndexedMedia
+    #  - DM Version          - T86VZV01 - T86VZV02: 4, T86VZV03: 5
+
 #-------------------------------------------------------------------------------
 parentprofile=com_lgvx8500.Profile
 class Profile(parentprofile):
@@ -78,6 +93,9 @@ class Profile(parentprofile):
         ('memo', 'write', 'OVERWRITE'),       # all memo list writing
 ##        ('playlist', 'read', 'OVERWRITE'),
 ##        ('playlist', 'write', 'OVERWRITE'),
-        ('t9_udb', 'read', 'OVERWRITE'),
         ('t9_udb', 'write', 'OVERWRITE'),
         )
+    if __debug__:
+        _supportedsyncs+=(
+        ('t9_udb', 'read', 'OVERWRITE'),
+        )
