@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_moto.py 3927 2007-01-22 03:15:22Z rogerb $
+### $Id: com_moto.py 4516 2007-12-21 22:00:57Z djpham $
 
 """Communicate with Motorola phones using AT commands.  This code is for all Motorola phones
 with specific subclasses for CDMA and GSM variants"""
@@ -283,7 +283,7 @@ class Phone(com_etsi.Phone):
             for _retry_cnt in range(2):
                 try:
                     self.progress(_end_idx, _total_entries,
-                                  'Reading conatct entry %d to %d'%(_start_idx, _end_idx))
+                                  'Reading contact entry %d to %d'%(_start_idx, _end_idx))
                     _res=self.sendATcommand(_req, self.protocolclass.read_pb_resp)
                     for _entry in _res:
                         self._build_pb_entry(_entry, pb_book, result)
@@ -448,7 +448,7 @@ class Phone(com_etsi.Phone):
                                                  retry=True)
                     self._process_sms_result(_res, _sms, fundamentals)
                 except commport.ATError:
-                    pass
+                    self.log('Failed to read SMS Item %d'%_sms_item.index)
         except:
             if __debug__:
                 self.setmode(self.MODEMODEM)
