@@ -5,16 +5,18 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_motoe815.py 3460 2006-07-08 23:55:09Z djpham $
+### $Id: com_motoe815.py 3918 2007-01-19 05:15:12Z djpham $
 
 """Communicate with Motorola E815 phones using AT commands"""
 
 # BitPim modules
 import com_motov710
+import helpids
 
 parentphone=com_motov710.Phone
 class Phone(parentphone):
     desc='Moto-E815'
+    helpid=helpids.ID_PHONE_MOTOE815
     serialsname='motoe815'
 
 #------------------------------------------------------------------------------
