@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_motov710.py 4533 2007-12-28 05:54:09Z djpham $
+### $Id: com_motov710.py 4600 2008-03-01 04:55:30Z djpham $
 
 """Communicate with Motorola phones using AT commands"""
 # system modules
@@ -47,10 +47,22 @@ class Phone(com_moto_cdma.Phone):
 
     def __init__(self, logtarget, commport):
         com_moto_cdma.Phone.__init__(self, logtarget, commport)
+        self._group_count=None
 
     # fundamentals stuff--------------------------------------------------------
     def _get_groups(self):
-        _req=self.protocolclass.read_group_req()
+        if self._group_count is None:
+            self._group_count=self.protocolclass.PB_TOTAL_GROUP
+            try:
+                _req=self.protocolclass.group_count_req()
+                _res=self.sendATcommand(_req, self.protocolclass.group_count_resp)
+                if len(_res)==1 and _res[0].countstring.startswith('(1-'):
+                    self._group_count=int(_res[0].countstring[3:-1])
+                    self.log('Group Count: %d' % self._group_count)
+            except:
+                if __debug__:
+                    raise
+        _req=self.protocolclass.read_group_req(end_index=self._group_count)
         _res=self.sendATcommand(_req, self.protocolclass.read_group_resp)
         res={}
         for e in _res:
