@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_samsungscha950.py 4567 2008-01-14 02:59:46Z djpham $
+### $Id: com_samsungscha950.py 4784 2010-01-15 01:44:50Z djpham $
 
 """Communicate with the Samsung SCH-A950 Phone"""
 
@@ -108,14 +108,13 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
             _path_name=self.protocolclass.GROUP_INDEX_FILE_NAME
             for i in range(256):
                 _name='%s%d'%(_path_name, i)
-                if self.statfile(_name):
+                if self.exists(_name):
                     _file_name=_name
                     break
             if not _file_name:
                 return _res
-            _buf=prototypes.buffer(self.getfilecontents(_file_name))
-            _index_file=self.protocolclass.GroupIndexFile()
-            _index_file.readfrombuffer(_buf)
+            _index_file=self.readobject(_file_name,
+                                        self.protocolclass.GroupIndexFile)
             for _entry in _index_file.items[1:]:
                 if _entry.name:
                     _res[_entry.index]={ 'name': _entry.name }
@@ -285,7 +284,7 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
                               fundamentals):
         _index=fundamentals.get(index_key, {})
         _media={}
-        for _key,_entry in _index.items():
+        for _entry in _index.values():
             if _entry.has_key('filename') and _entry['filename']:
                 try:
                     _media[_entry['name']]=self.getfilecontents(_entry['filename'],
@@ -365,9 +364,10 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
         
     def _add_files(self, index_key, media_key,
                    new_list, fundamentals):
-        """Add new file using BEW"""
+        """Add new file using BREW"""
         _index=fundamentals.get(index_key, {})
         _media=fundamentals.get(media_key, {})
+        _res=[]
         for _file in new_list:
             _data=self._item_from_index(_file, 'data', _media)
             if not _data:
@@ -388,10 +388,12 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
                 _file_name=_path+'/'+_file
                 try:
                     self.writefile(_file_name, _data)
+                    _res.append(_file)
                 except:
                     self.log('Failed to write file '+_file_name)
                     if __debug__:
                         raise
+        return _res
 
     def _update_media_index(self, index_file_class, index_entry_class,
                             media_path, excluded_files,
@@ -490,19 +492,19 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
 
     # Calendar stuff------------------------------------------------------------
     def _read_calendar_index(self):
-        _buf=prototypes.buffer(self.getfilecontents(self.protocolclass.CAL_INDEX_FILE_NAME))
-        _res=self.protocolclass.CalIndexFile()
-        _res.readfrombuffer(_buf)
-        return _res
+        return self.readobject(self.protocolclass.CAL_INDEX_FILE_NAME,
+                               self.protocolclass.CalIndexFile,
+                               'Reading Calendar Index File')
     
     def getcalendar(self, fundamentals):
         self.log('Reading calendar')
         _cal_index=self._read_calendar_index()
         _res={}
+        _buf=prototypes.buffer()
         for _cnt in range(_cal_index.numofevents):
             _cal_file_name='%s%04d'%(self.protocolclass.CAL_FILE_NAME_PREFIX,
                                      _cal_index.events[_cnt].index)
-            _buf=prototypes.buffer(self.getfilecontents(_cal_file_name))
+            _buf.reset(self.getfilecontents(_cal_file_name))
             _bpcal=self.calendarclass(self, _buf, fundamentals).getvalue()
             _res[_bpcal.id]=_bpcal
         fundamentals['calendar']=_res
@@ -531,11 +533,10 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
                 break
             try:
                 _cal_entry=self.calendarclass(self, _entry, fundamentals)
-                _buf=prototypes.buffer()
-                _cal_entry.writetobuffer(_buf)
                 _cal_file_name='%s%04d'%(self.protocolclass.CAL_FILE_NAME_PREFIX,
                                          _idx)
-                self.writefile(_cal_file_name, _buf.getvalue())
+                self.writeobject(_cal_file_name, _cal_entry,
+                                 'Writing Calendar Entry')
                 _idx+=1
                 _cnt+=1
             except:
@@ -562,10 +563,9 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
             _cal_index.events[_cnt].index=_idx
             _cal_index.activeevents[_cnt].index=_idx
             _cnt+=1
-        _buf=prototypes.buffer()
-        _cal_index.writetobuffer(_buf)
-        self.writefile(self.protocolclass.CAL_INDEX_FILE_NAME,
-                       _buf.getvalue())
+        self.writeobject(self.protocolclass.CAL_INDEX_FILE_NAME,
+                         _cal_index,
+                         'Writing Calendar Index File')
 
     def savecalendar(self, fundamentals, merge):
         self.log("Sending calendar entries")
@@ -584,11 +584,11 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
         for _idx in range(_index_file.numofnotes):
             _file_name='%s%04d'%(self.protocolclass.NP_FILE_NAME_PREFIX,
                                  _index_file.notes[_idx].index)
-            _buf=prototypes.buffer(self.getfilecontents(_file_name))
-            _note=self.protocolclass.NotePadEntry()
-            _note.readfrombuffer(_buf)
+            _note=self.readobject(_file_name,
+                                  self.protocolclass.NotePadEntry)
             _memo=memo.MemoEntry()
             _memo.text=_note.text
+            _memo.set_date_isostr('%04d%02d%02dT%02d%02d00'%_note.modified[:5])
             _res[_memo.id]=_memo
         fundamentals['memo']=_res
         return fundamentals
@@ -621,11 +621,10 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
                 _memo_entry.textlen=_text_len
                 _memo_entry.text=_entry.text[:_text_len]
                 _memo_entry.creation=self._time_now()
-                _buf=prototypes.buffer()
-                _memo_entry.writetobuffer(_buf)
                 _file_name='%s%04d'%(self.protocolclass.NP_FILE_NAME_PREFIX,
                                      _idx)
-                self.writefile(_file_name, _buf.getvalue())
+                self.writeobject(_file_name, _memo_entry,
+                                 logtitle='Writing memo entry')
                 _idx+=1
                 _cnt+=1
             except:
@@ -648,10 +647,9 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
         for _idx in range(_old_next_index, next_index):
             _file_index.notes[_cnt].index=_idx
             _cnt+=1
-        _buf=prototypes.buffer()
-        _file_index.writetobuffer(_buf)
-        self.writefile(self.protocolclass.CAL_INDEX_FILE_NAME,
-                       _buf.getvalue())
+        self.writeobject(self.protocolclass.CAL_INDEX_FILE_NAME,
+                         _file_index,
+                         logtitle='Writing calendar/memo file index')
         
     def savememo(self, fundamentals, merge):
         self.log('Writing memo/notepad items')
@@ -676,7 +674,8 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
             try:
                 self.sendbrewcommand(req, respc, callsetmode=False)
                 return True
-            except com_phone.modeignoreerrortypes:
+            except (com_phone.modeignoreerrortypes,
+                    ValueError):
                 pass
         return False
     def check_my_phone(self, res):
@@ -731,12 +730,14 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
             _buf=prototypes.buffer(self.getfilecontents(filename))
             _rec_file=self.protocolclass.PBFileHeader()
             _rec_file.readfrombuffer(_buf)
+            _entry=self.protocolclass.PBEntry()
             for _len in _rec_file.lens:
                 if _len.itemlen:
-                    _entry=self.protocolclass.PBEntry()
+                    _buf_ofs=_buf.offset
                     _entry.readfrombuffer(_buf)
-                    _pbentry=self.pbentryclass(self, _entry, fundamentals).getvalue()
-                    res[len(res)]=_pbentry
+                    _buf.offset=_buf_ofs+_len.itemlen
+                    res[len(res)]=self.pbentryclass(self, _entry,
+                                                    fundamentals).getvalue()
         except:
             self.log('Failed to read file: %s'%filename)
             if __debug__:
@@ -749,7 +750,7 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
         while True:
             _file_name='%s%04d'%(self.protocolclass.PB_ENTRY_FILE_PREFIX,
                                  _file_cnt)
-            if self.statfile(_file_name):
+            if self.exists(_file_name):
                 self._extract_entries(_file_name, _res, fundamentals)
                 _file_cnt+=1
             else:
@@ -777,7 +778,8 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
             if not _img.Ok():
                 self.log('Failed to understand image: '+filename)
                 return
-            _img.Rescale(128, 96)
+            _img.Rescale(self.protocolclass.PB_WP_CACHE_WIDTH,
+                         self.protocolclass.PB_WP_CACHE_HEIGHT)
             _img.SaveFile(_tmpname, wx.BITMAP_TYPE_JPEG)
             _newfilename=self.protocolclass.PB_WP_CACHE_PATH+'/$'+filename.replace('/', '$')
             _data=file(_tmpname, 'rb').read()
@@ -857,9 +859,9 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
         # read the index file and return the number of incoming, outgoing, and
         # missed calls
         try:
-            _buf=prototypes.buffer(self.getfilecontents(self.protocolclass.CL_INDEX_FILE))
-            _req=self.protocolclass.cl_index_file()
-            _req.readfrombuffer(_buf, 'Reading Call Log Index File')
+            _req=self.readobject(self.protocolclass.CL_INDEX_FILE,
+                                 self.protocolclass.cl_index_file,
+                                 logtitle='Reading Call Log Index File')
             return ([x.index for x in _req.incoming[:_req.incoming_count]],
                     [x.index for x in _req.outgoing[:_req.outgoing_count]],
                     [x.index for x in _req.missed[:_req.missed_count]])
@@ -872,9 +874,10 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
     def _get_ch(self, call_list, folder, res):
         # read the call history files
         _req=self.protocolclass.cl_file()
+        _buf=prototypes.buffer()
         for _idx in call_list:
             try:
-                _buf=prototypes.buffer(self.getfilecontents(
+                _buf.reset(self.getfilecontents(
                     '%s%02d'%(self.protocolclass.CL_PREFIX, _idx)))
                 _req.readfrombuffer(_buf, 'Reading Call Log File')
                 if _req.valid:
@@ -1040,8 +1043,8 @@ class CalendarEntry(object):
         else:
             raise TypeError('Expecting type bpcalendar.CalendarEntry or prototypes.buffer')
 
-    def writetobuffer(self, buf):
-        self.cal.writetobuffer(buf)
+    def writetobuffer(self, buf, logtitle=None):
+        self.cal.writetobuffer(buf, logtitle=logtitle)
 
     # building routines---------------------------------------------------------
     _build_repeat_dict={
@@ -1178,8 +1181,8 @@ class PBEntry(object):
         else:
             raise TypeError('Should be PBEntry or phone dict')
 
-    def writetobuffer(self, buf):
-        self.pb.writetobuffer(buf)
+    def writetobuffer(self, buf, logtitle=None):
+        self.pb.writetobuffer(buf, logtitle=logtitle)
 
     # Building a phonebook rec from a bp phone dict-----------------------------
     _pb_type_dict={
@@ -1261,9 +1264,9 @@ class PBEntry(object):
     # Extracting data from the phone--------------------------------------------
     def _extract_emails(self, entry, p_class):
         # extract emails
-        if self.pb.info & p_class.PB_FLG_EMAIL:
+        if self.pb.has_email:
             entry['emails']=[{ 'email': self.pb.email }]
-        if self.pb.info & p_class.PB_FLG_EMAIL2:
+        if self.pb.has_email2:
             entry.setdefault('emails', []).append({ 'email': self.pb.email2 })
     _number_type_dict={
         'cell': (Phone.protocolclass.PB_FLG_CELL, 'cell'),
@@ -1280,29 +1283,29 @@ class PBEntry(object):
                 _num_entry=getattr(self.pb, _key)
                 _number={ 'number': _num_entry.number,
                           'type': _info_list[1] }
-                if _num_entry.option&p_class.PB_FLG_SPEEDDIAL:
+                if _num_entry.has_speeddial:
                     _number['speeddial']=_num_entry.speeddial
-                if _num_entry.option&p_class.PB_FLG_RINGTONE and \
+                if _num_entry.has_ringtone and \
                    not entry.has_key('ringtones'):
                     _ringtone=self.phone.ringtone_name_from_range(
                         _num_entry.ringtone, self.fundamentals)
                     if _ringtone:
                         entry['ringtones']=[{ 'ringtone': _ringtone,
                                               'use': 'call' }]
-                if _num_entry.option & p_class.PB_FLG_PRIMARY:
+                if _num_entry.is_primary:
                     # this is the primary number, insert to the beginning
                     entry['numbers']=[_number]+entry['numbers']
                 else:
                     entry['numbers'].append(_number)
     def _extract_group(self, entry, p_class):
-        if not self.pb.info&p_class.PB_FLG_GROUP:
+        if not self.pb.has_group:
             # no group specified
             return
         _groups=self.fundamentals.get('groups', {})
         if _groups.has_key(self.pb.group):
             entry['categories']=[{ 'category': _groups[self.pb.group]['name'] }]
     def _extract_wallpaper(self, entry, p_class):
-        if not self.pb.info&p_class.PB_FLG_WP:
+        if not self.pb.has_wallpaper:
             return
         _idx=self.pb.wallpaper.rfind('$')+1
         _wp=self.pb.wallpaper[_idx:]
