@@ -6,7 +6,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_samsungspha620.py 3918 2007-01-19 05:15:12Z djpham $
+### $Id: com_samsungspha620.py 4371 2007-08-22 04:22:40Z sawecw $
 
 """Communicate with a Samsung SPH-A620"""
 
@@ -199,7 +199,7 @@ class Phone(com_samsung_packet.Phone):
                 contents=self.getfilecontents(filename)
 
                 name_len=ord(contents[5])
-                new_basefilename=contents[6:6+name_len]+".jpg"
+                new_basefilename=filename[p+1:]+"_"+contents[6:6+name_len]+".jpg"
                 duplicate=False
                 # Fix up duplicate filenames
                 for k in results[index_key].keys():
