@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_samsungspha790.py 3460 2006-07-08 23:55:09Z djpham $
+### $Id: com_samsungspha790.py 4365 2007-08-17 21:11:59Z djpham $
 
 """Communicate with a Samsung SPH-A790"""
 # System modules
@@ -223,9 +223,10 @@ class Phone(parentphone):
 
     getringtones=NotImplemented
 
-    def _detectphone(coms, likely_ports, res, _module, _log):
+    @classmethod
+    def detectphone(_, coms, likely_ports, res, _module, _log):
         pass
-    detectphone=staticmethod(_detectphone)
+
 #-------------------------------------------------------------------------------
 parentprofile=com_samsung_packet.Profile
 class Profile(parentprofile):
