@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_sanyo6600.py 4097 2007-03-13 21:39:19Z djpham $
+### $Id: com_sanyo6600.py 4531 2007-12-28 04:23:09Z sawecw $
 
 """Talk to the Sanyo Katana (SCP-6600) cell phone"""
 # standard modules
@@ -81,8 +81,6 @@ class Phone(com_sanyo3100.Phone):
 
     def getfundamentals(self, results):
         """Gets information fundamental to interopating with the phone and UI."""
-        req=self.protocolclass.esnrequest()
-        res=self.sendpbcommand(req, self.protocolclass.esnresponse)
         results['uniqueserial']=sha.new(self.get_esn()).hexdigest()
         self.getmediaindices(results)
 
@@ -471,7 +469,8 @@ class Phone(com_sanyo3100.Phone):
         self.progress(1,1, "Phonebook write completed")
         data['rebootphone']=1
 
-    my_model='SCP-6600/US'
+    my_model='SCP6600'
+    detected_model='SCP-6600/US'
     my_manufacturer='SANYO'
 
 parentprofile=com_sanyo3100.Profile
