@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_sanyo7500.py 4086 2007-03-11 04:49:43Z sawecw $
+### $Id: com_sanyo7500.py 4598 2008-02-24 04:59:42Z sawecw $
 
 """Talk to the Sanyo MM-7500 cell phone"""
 # standard modules
@@ -63,7 +63,8 @@ class Phone(com_sanyo3100.Phone):
         self.mode=self.MODENONE
         self.numbertypetab=numbertypetab
 
-    my_model='SCP-7500/US'
+    my_model='SCP7500'
+    detected_model='SCP-7500/US'
     my_manufacturer='SANYO'
 
 parentprofile=com_sanyo3100.Profile
