@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_sanyomedia.py 3637 2006-11-05 16:25:01Z sawecw $
+### $Id: com_sanyomedia.py 3707 2006-11-29 04:49:48Z sawecw $
 
 """Common code for Sanyo Media transfers"""
 
@@ -60,7 +60,14 @@ class SanyoMedia:
             req.dirindex=idir
             res=self.sendpbcommand(req, self.protocolclass.sanyochangedirresponse)
             req=self.protocolclass.sanyonumfilesrequest()
-            res=self.sendpbcommand(req, self.protocolclass.sanyonumfilesresponse)
+            try:
+                res=self.sendpbcommand(req, self.protocolclass.sanyonumfilesresponse)
+            except com_sanyo.SanyoCommandException, ex:
+                if ex.errnum!=121:
+                    raise
+                self.log("Skipping directory "+`idir`)
+                continue
+            
             self.log("Directory "+`idir`+", File Count="+`res.count`)
             nfiles=res.count
             for ifile in range(nfiles):
@@ -164,7 +171,14 @@ class SanyoMedia:
             req.dirindex=idir
             res=self.sendpbcommand(req, self.protocolclass.sanyochangedirresponse)
             req=self.protocolclass.sanyonumfilesrequest()
-            res=self.sendpbcommand(req, self.protocolclass.sanyonumfilesresponse)
+            try:
+                res=self.sendpbcommand(req, self.protocolclass.sanyonumfilesresponse)
+            except com_sanyo.SanyoCommandException, ex:
+                if ex.errnum!=121:
+                    raise
+                self.log("Skipping directory "+`idir`)
+                continue
+
             self.log("Directory "+`idir`+", File Count="+`res.count`)
             nfiles=res.count
             for ifile in range(nfiles):
