@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: prototypes.py 4660 2008-08-03 17:23:40Z hjelmn $
+### $Id: prototypes.py 4784 2010-01-15 01:44:50Z djpham $
 
 """The various types used in protocol descriptions
 
@@ -86,6 +86,9 @@ class MissingQuotesException(ProtogenException):
 
 class BaseProtogenClass(object):
     """All types are derived from this"""
+    def __init__(self, *args, **kwargs):
+        pass
+
     def packetsize(self):
         "Returns size in bytes that we occupy"
         # This is implemented by writing to a buffer and seeing how big the result is.
@@ -533,7 +536,14 @@ class USTRING(BaseProtogenClass):
             self._write_encoding=self._encoding
         if self._terminator_length < 1 or self._terminator_length > 4:
             raise ValueException("Terminator length outside allowed range of 1-4.  You tried setting it to %d" % self._terminator_length)
-        
+
+        # detect correct terminator length
+        if self._terminator == 0:
+            if self._encoding.startswith("utf_16"):
+                self._terminator_length = 2
+            elif self._encoding.startswith("utf_32"):
+                self._terminator_length = 4
+
         # Set our value if one was specified
         if len(args)==0:
             pass
@@ -649,7 +659,7 @@ class USTRING(BaseProtogenClass):
                     _value=_value[:-1]
 
         if self._maxsizeinbytes is not None:
-            self._value=self._value[:self._maxsizeinbytes]
+            _value=_value[:self._maxsizeinbytes]
 
         if self._constant is not None and _value!=self._constant:
             raise ValueException("The value read was not the constant")
@@ -672,6 +682,8 @@ class USTRING(BaseProtogenClass):
         self._bufferstartoffset=buf.getcurrentoffset()
         # calculate length
         temp_str=self.convert_for_write()
+        # this length is the character length of the string NOT the byte length (BIG DIFFERENCE)
+        # the byte length is calculated below
         l=len(temp_str)
         if self._terminator is not None:
             l+=1
@@ -684,6 +696,10 @@ class USTRING(BaseProtogenClass):
             for j in range(self._terminator_length):
                 buf.appendbyte((term & 0xFF))
                 term=term>>8
+        # calculate the byte length
+        self._bufferendoffset=buf.getcurrentoffset()
+        l = self._bufferendoffset - self._bufferstartoffset
+        # pad the buffer
         if self._sizeinbytes is not None:
             if l<self._sizeinbytes:
                 buf.appendbytes(chr(self._pad)*(self._sizeinbytes-l))
@@ -717,6 +733,7 @@ class USTRING(BaseProtogenClass):
         """Returns the string we are"""
         if self._value is None:
             raise ValueNotSetException()
+
         # convert to unicode if we are not already
         if not isinstance(self._value, unicode):
             try:
@@ -1345,6 +1362,77 @@ class DATA(BaseProtogenClass):
             raise ValueNotSetException()
         return self._value
 
+class DONTCARE(BaseProtogenClass):
+    "Block of bytes that we don't know and don't care for"
+    def __init__(self, *args, **kwargs):
+        """
+        A data value can be specified to this constructor or in the value keyword arg
+
+        @keyword sizeinbytes: Length of block
+             If not set, then the rest of the packet will be consumed on reads.
+        @keyword default: (Optional) Our default value, could be either a char or string.
+        @keyword storage: (Optional) True or False: whether to store the data or ignore.
+        """
+        super(DONTCARE, self).__init__(*args, **kwargs)
+        
+        self._sizeinbytes=None
+        self._default='\x00'
+        self._storage=False
+        self._value=None
+
+        if self._ismostderived(DONTCARE):
+            self._update(args,kwargs)
+
+    def _update(self, args, kwargs):
+        super(DONTCARE, self)._update(args, kwargs)
+
+        self._consumekw(kwargs, ("sizeinbytes", "default", "storage", "value"))
+        self._complainaboutunusedargs(DONTCARE, kwargs)
+
+        # Set our value if one was specified
+        if len(args)==0:
+            pass
+        elif len(args)==1:
+            if self._storage:
+                self._value=args[0]
+        else:
+            raise TypeError("Unexpected arguments "+`args`)
+        # must specify the length of the block
+        if self._sizeinbytes is None:
+            raise ValueException("sizeinbytes must be specified for DONTCARE")
+        # check for valid length 
+        if self._storage and self._value is not None and \
+           len(self._value)!=self._sizeinbytes:
+            raise ValueLengthException(len(self._value), self._sizeinbytes)
+        if len(self._default)>1 and len(self._default)!=self._sizeinbytes:
+            raise ValueLengthException(len(self._default), self._sizeinbytes)
+
+    def readfrombuffer(self, buf):
+        self._bufferstartoffset=buf.getcurrentoffset()
+        if self._storage:
+            # read & store
+            self._value=buf.getnextbytes(self._sizeinbytes)
+        else:
+            # just ignore it
+            buf.discardnextbytes(self._sizeinbytes)
+        self._bufferendoffset=buf.getcurrentoffset()
+
+    def writetobuffer(self, buf):
+        self._bufferstartoffset=buf.getcurrentoffset()
+        buf.appendbytes(self.getvalue())
+        self._bufferendoffset=buf.getcurrentoffset()
+
+    def packetsize(self):
+        return self._sizeinbytes
+
+    def getvalue(self):
+        """Returns the bytes we are"""
+        if self._value is not None:
+            return self._value
+        elif len(self._default)>1:
+            return self._default
+        else:
+            return self._default*self._sizeinbytes
 
 class UNKNOWN(DATA):
     "A block of bytes whose purpose we don't know"
@@ -1535,10 +1623,14 @@ class buffer(object):
     "This is used for reading and writing byte data"
     def __init__(self, data=None):
         "Call with data to read from it, or with None to write to it"
-        if data is not None:
-            self._data=data
-        else:
+        self.reset(data)
+
+    def reset(self, data=None):
+        "Call with data to read from it, or with None to write to it"
+        if data is None:
             self._buffer=cStringIO.StringIO()
+        else:
+            self._data=data
 
         self._offset=0
 
@@ -1585,6 +1677,16 @@ class buffer(object):
         sz=len(self._data)-self._offset
         return self.getnextbytes(sz)
 
+    def discardnextbytes(self, howmany):
+        "Discards howmany bytes"
+        if self._offset+howmany>len(self._data):
+            raise IndexError("Trying to discard "+`howmany`+" bytes starting at "+`self._offset`+" which will go beyond end of "+`len(self._data)`+" byte buffer")
+        self._offset+=howmany
+
+    def discardremainingbytes(self):
+        "Discards the rest of the buffer"
+        self._offset=len(self._data)
+
     def hasmore(self):
         "Is there any data left?"
         return self._offset<len(self._data)
