@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: prototypes_samsung.py 4527 2007-12-26 03:09:36Z djpham $
+### $Id: prototypes_samsung.py 4777 2010-01-07 03:24:27Z djpham $
 
 """The various types used in protocol descriptions specific to Samsung phones"""
 
@@ -42,8 +42,8 @@ class DateTime(prototypes.UINTlsb):
 
     _time_delta=315514800.0
     def _converttoint(self, date):
-        assert len(date)==5
-        _timetuple=datetime.datetime(*date).timetuple()[:-1]+(DateTime._daylight,)
+        assert len(date)>4
+        _timetuple=datetime.datetime(*date[:5]).timetuple()[:-1]+(DateTime._daylight,)
         return int(calendar.timegm(_timetuple)-self._time_delta)
 
     def getvalue(self):
