@@ -6,7 +6,9 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: ringers.py 3608 2006-10-06 02:51:56Z djpham $
+### $Id: ringers.py 4379 2007-08-28 03:06:58Z djpham $
+
+from __future__ import with_statement
 
 import os
 import time
@@ -22,7 +24,7 @@ import common
 import fileinfo
 import conversions
 import helpids
-
+import guihelper
 import rangedslider
 
 ###
@@ -170,16 +172,16 @@ class RingerView(fileview.FileView):
         if max_size is not None and len(filedata)>max_size:
             # the data is too big
             self.log('ringtone %s is too big!'%common.basename(file))
-            dlg=wx.MessageDialog(self,
-                                 'Ringtone %s may be too big.  Do you want to proceed anway?'%common.basename(file),
-                                 'Warning',
-                                 style=wx.YES_NO|wx.ICON_ERROR)
-            dlg_resp=dlg.ShowModal()
-            dlg.Destroy()
-            if dlg_resp==wx.ID_NO:
-                return
+            with guihelper.WXDialogWrapper(wx.MessageDialog(self,
+                                                            'Ringtone %s may be too big.  Do you want to proceed anway?'%common.basename(file),
+                                                            'Warning',
+                                                            style=wx.YES_NO|wx.ICON_ERROR),
+                                           True) as (dlg, dlg_resp):
+                if dlg_resp==wx.ID_NO:
+                    return
         self.AddToIndex(name, origin, filedata, self._data, mtime)
-        
+
+    @guihelper.BusyWrapper
     def OnAddFiles(self, filenames):
         for file in filenames:
             if file is None: continue  # failed dragdrop?
@@ -211,28 +213,21 @@ class RingerView(fileview.FileView):
                 if max_size is not None and len(filedata)>max_size:
                     # the data is too big
                     self.log('ringtone %s is too big!'%common.basename(file))
-                    dlg=wx.MessageDialog(self,
-                                         'Ringtone %s may be too big.  Do you want to proceed anway?'%common.basename(file),
-                                         'Warning',
-                                         style=wx.YES_NO|wx.ICON_ERROR)
-                    dlg_resp=dlg.ShowModal()
-                    dlg.Destroy()
-                    if dlg_resp==wx.ID_NO:
-                        continue
+                    with guihelper.WXDialogWrapper(wx.MessageDialog(self,
+                                                                    'Ringtone %s may be too big.  Do you want to proceed anway?'%common.basename(file),
+                                                                    'Warning',
+                                                                    style=wx.YES_NO|wx.ICON_ERROR),
+                                                   True) as (dlg, dlg_resp):
+                        if dlg_resp==wx.ID_NO:
+                            continue
                 target=self.get_media_name_from_filename(file, newext)
                 self.AddToIndex(target, self.active_section, filedata, self._data, mtime)
         self.OnRefresh()
 
-    OnAddFiles=guihelper.BusyWrapper(OnAddFiles)
-
     def ConvertFormat(self, file, convertinfo):
-        dlg=ConvertDialog(self, file, convertinfo)
-        if dlg.ShowModal()==wx.ID_OK:
-            res=dlg.newfiledata
-        else:
-            res=None
-        dlg.Destroy()
-        return res
+        with guihelper.WXDialogWrapper(ConvertDialog(self, file, convertinfo),
+                                       True) as (dlg, retcode):
+            return dlg.newfiledata if retcode==wx.ID_OK else None
 
     def versionupgrade(self, dict, version):
         """Upgrade old data format read from disk
@@ -447,7 +442,7 @@ class ConvertDialog(wx.Dialog):
                       self.clip_duration.GetId(), self.clip_volume.GetId(),
                       clip_set_btn.GetId()]
 
-
+    @guihelper.BusyWrapper
     def OnConvert(self, _):
         self.OnStop()
         for i in self.cropids:
@@ -463,9 +458,6 @@ class ConvertDialog(wx.Dialog):
             self.FindWindowById(i).Enable(True)
         self.FindWindowById(wx.ID_OK).Enable(True)
 
-    OnConvert=guihelper.BusyWrapper(OnConvert)
-
-
     def UpdateCrop(self):
         self.positionlabel.SetLabel("%.1f secs" % (self.slider.GetCurrent()*self.wfi.duration),)
         duration=(self.slider.GetEnd()-self.slider.GetStart())*self.wfi.duration
@@ -540,7 +532,8 @@ class ConvertDialog(wx.Dialog):
         for file in self.temporaryfiles:
             if os.path.exists(file):
                 os.remove(file)
-        
+
+    @guihelper.BusyWrapper
     def OnOk(self, evt):
         self.OnStop()
         # make new data
@@ -595,17 +588,12 @@ class ConvertDialog(wx.Dialog):
 
     def _trim_mp3(self, start, duration):
         # mp3 writing out
-        f=None
-        try:
-            frames=self.afi.frames
-            offset=frames[self.beginframe].offset
-            length=frames[self.endframe-1].nextoffset-offset
-            f=open(self.mp3file, "rb", 0)
+        frames=self.afi.frames
+        offset=frames[self.beginframe].offset
+        length=frames[self.endframe-1].nextoffset-offset
+        with file(self.mp3file, 'rb', 0) as f:
             f.seek(offset)
             return f.read(length)
-        finally:
-            if f is not None:
-                f.close()
 
     def _trim_and_adjust_vol_mp3(self, start, duration, volume):
         # trim, adjust volume, and write mp3 out
@@ -660,4 +648,4 @@ class ConvertDialog(wx.Dialog):
             conversions.adjustwavfilevolume(self.wavfile, volume)
         conversions.convertwavtoqcp(self.wavfile, self.qcpfile,
                                     self.optimization.GetSelection())
-        return open(self.qcpfile, "rb").read()
+        return file(self.qcpfile, "rb").read()
