@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: today.py 4365 2007-08-17 21:11:59Z djpham $
+### $Id: today.py 4601 2008-03-04 22:37:48Z djpham $
 
 """
 Code to handle BitPim Today tab.
@@ -159,6 +159,7 @@ def send_request_event():
     pubsub.publish(pubsub.REQUEST_TODAY_DATA)
 
 #-------------------------------------------------------------------------------
+EVT_HYPERLINK_LEFT=hl.EVT_HYPERLINK_LEFT
 class HyperLinkCtrl(hl.HyperLinkCtrl):
     def __init__(self, *args, **kargs):
         super(HyperLinkCtrl, self).__init__(*args, **kargs)
@@ -166,6 +167,16 @@ class HyperLinkCtrl(hl.HyperLinkCtrl):
         self.DoPopup(False)
         self.client_data=None
 
+    def SetToolTip(self, tip):
+        if isinstance(tip, (str, unicode)):
+            super(HyperLinkCtrl, self).SetToolTip(wx.ToolTip(tip))
+        else:
+            super(HyperLinkCtrl, self).SetToolTip(tip)
+
+    def SetLabel(self, label):
+        super(HyperLinkCtrl, self).SetLabel(label)
+        self.SetToolTip(label)
+
 #-------------------------------------------------------------------------------
 class StaticText(wx.StaticText):
     _max_item_len=30
