@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: todo.py 4379 2007-08-28 03:06:58Z djpham $
+### $Id: todo.py 4459 2007-11-24 07:55:33Z djpham $
 
 """
 Code to handle Todo Items
@@ -349,7 +349,7 @@ class DateControl(wx.Panel, widgets.BitPimWidget):
             dt=datetime.date.today()
         else:
             dt=self._dt
-        with guihelper.WXDailogWrapper(wx.lib.calendar.CalenDlg(self,
+        with guihelper.WXDialogWrapper(wx.lib.calendar.CalenDlg(self,
                                                                 month=dt.month,
                                                                 day=dt.day,
                                                                 year=dt.year)) as dlg:
