@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: vcal_calendar.py 4396 2007-09-12 21:44:00Z djpham $
+### $Id: vcal_calendar.py 4708 2008-09-06 04:10:44Z djpham $
 
 "Deals with vcard calendar import stuff"
 
@@ -68,8 +68,19 @@ class vCalendarFile(object):
                         _params[_l[0]]=None
                     else:
                         _params[_l[0]]=_l[1]
-                d[n[0]]={ 'value': l,
-                          'params': _params }
+                # Some statement, i.e. EXDATE, may occur more than once,
+                # in such cases, place the values into the list
+                # This may break existing cases, but we'll fix them as
+                # users report them
+                _val={ 'value': l, 'params': _params }
+                if d.has_key(n[0]):
+                    # multiple statements
+                    if isinstance(d[n[0]], dict):
+                        d[n[0]]=[d[n[0]], _val]
+                    else:
+                        d[n[0]].append(_val)
+                else:
+                    d[n[0]]=_val
         if module_debug:
             print d,'\n'
         return d
@@ -183,10 +194,7 @@ class VCalendarImportData(object):
             rp.repeat_type=rp_type
             rp.interval=rp_interval
             rp.interval2=rp_interval2
-            if rp_dow:
-                rp.dow=rp_dow
-            else:
-                rp.dow=ce.start
+            rp.dow=rp_dow
         elif rp_type==rp.yearly:
             rp.repeat_type=rp.yearly
         else:
@@ -428,10 +436,11 @@ class VCalendarImportData(object):
         return func_dict.get(c, lambda *arg: False)(v, dd)
     def _conv_exceptions(self, v, _):
         try:
-            l=v['value'].split(';')
+            _val=v if isinstance(v, (list, tuple)) else [v]
             r=[]
-            for n in l:
-                r.append(bptime.BPTime(n).get())
+            for _item in _val:
+                for n in _item['value'].split(';'):
+                    r.append(bptime.BPTime(n).get())
             return r
         except:
             if __debug__:
@@ -469,6 +478,11 @@ class VCalendarImportData(object):
                     dd['start']=dd['end']
                 elif dd['end'] is None:
                     dd['end']=dd['start']
+                if dd.get('allday', False) and dd['end']>dd['start']:
+                    # All day event, adjust the end time as necessary
+                    dd['end']=(bptime.BPTime(dd['end'])-\
+                               bptime.timedelta(days=1)).get()[:3]+(0, 0)
+
                 if module_debug: print dd
                 d.append(dd)
             except:
