@@ -5,13 +5,13 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: vcard.py 3619 2006-10-20 03:50:15Z djpham $
+### $Id: vcard.py 4369 2007-08-20 01:59:33Z djpham $
 
 """Code for reading and writing Vcard
 
 VCARD is defined in RFC 2425 and 2426
 """
-
+from __future__ import with_statement
 import sys
 import quopri
 import base64
@@ -581,7 +581,7 @@ class VCard:
         # handle a few PALM custom fields
         ff=field[0].split(".")
         f0=ff[0]
-        f1=len(ff)>1 and ff[1] or ''
+        f1=ff[1] if len(ff)>1 else ''
         if f0.startswith('X-PALM-CATEGORY') or f1.startswith('X-PALM-CATEGORY'):
             self._field_CATEGORIES(['CATEGORIES'], value, result)
         elif f0=='X-PALM-NICKNAME' or f1=='X-PALM-NICKNAME':
@@ -593,7 +593,7 @@ class VCard:
     def _default_field(self, field, value, result):
         ff=field[0].split(".")
         f0=ff[0]
-        f1=len(ff)>1 and ff[1] or ''
+        f1=ff[1] if len(ff)>1 else ''
         if f0.startswith('X-PALM-') or f1.startswith('X-PALM-'):
             self._field_X_PALM(field, value, result)
             return
@@ -867,7 +867,7 @@ def out_tel_scp6600(vals, formatter):
     _pref=len(vals)>1
     for v in vals:
         res+=out_line("TEL",
-                      ["TYPE=%s%s" % (_pref and "PREF," or "",
+                      ["TYPE=%s%s" % ("PREF," if _pref else "",
                                       _out_tel_mapping[v['type']])],
                       phonenumber.format(v['number']), formatter)
         _pref=False
@@ -997,10 +997,9 @@ if __name__=='__main__':
         except UnicodeError:
             common.unicode_execfile(sys.argv[1], d,d)
     
-        f=open(sys.argv[2], "wt")
-        for k in d['result']['phonebook']:
-            print >>f, output_entry(d['result']['phonebook'][k], profile)
-        f.close()
+        with file(sys.argv[2], "wt") as f:
+            for k in d['result']['phonebook']:
+                print >>f, output_entry(d['result']['phonebook'][k], profile)
 
     if len(sys.argv)==2:
         # import bp
