@@ -5,11 +5,12 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: wallpaper.py 4226 2007-05-09 21:21:04Z djpham $
+### $Id: wallpaper.py 4410 2007-09-26 20:59:26Z djpham $
 
 "Deals with wallpaper and related views"
 
 # standard modules
+from __future__ import with_statement
 import os
 import sys
 import cStringIO
@@ -192,14 +193,10 @@ class WallpaperView(fileview.FileView):
         @return: (wxImage, filesize)
         """
         # find the image
-        data=None
-        for x in self._data[self.database_key]:
-            if origin==None or self._data[self.database_key][x].origin==origin:
-                if name==self._data[self.database_key][x].name:
-                    data=self._data[self.database_key][x].mediadata
-        if data!=None:
-            return self.GetImageFromString(data, None)
-        return None
+        for _, _item in self._data[self.database_key].items():
+            if (origin is None or _item.origin==origin) and \
+               _item.name==name:
+                    return self.GetImageFromString(_item.mediadata, None)
 
     # This function exists because of the constraints of the HTML
     # filesystem stuff.  The previous code was reading in the file to
@@ -286,9 +283,8 @@ class WallpaperView(fileview.FileView):
                 else:
                     img=wx.Image(file)
                 if not img.Ok():
-                    dlg=wx.MessageDialog(self, "Failed to understand the image in '"+file+"'",
-                                        "Image not understood", style=wx.OK|wx.ICON_ERROR)
-                    dlg.ShowModal()
+                    guihelper.MessageDialog(self, "Failed to understand the image in '"+file+"'",
+                                            "Image not understood", style=wx.OK|wx.ICON_ERROR)
                     continue
                 self.OnAddImage(img,file,refresh=False, timestamp=mtime)
         self.OnRefresh()
@@ -303,106 +299,75 @@ class WallpaperView(fileview.FileView):
         else:
             img=wx.Image(new_file_name)
         if not img.Ok():
-            dlg=wx.MessageDialog(self, "Failed to understand the image in '"+new_file_name+"'",
-                                "Image not understood", style=wx.OK|wx.ICON_ERROR)
-            dlg.ShowModal()
-            dlg.Destroy()
-            return
-        dlg=ImagePreviewDialog(self, img, self.mainwindow.phoneprofile, self.active_section)
-        if dlg.ShowModal()!=wx.ID_OK:
-            dlg.Destroy()
+            guihelper.MessageDialog(self, "Failed to understand the image in '"+new_file_name+"'",
+                                    "Image not understood", style=wx.OK|wx.ICON_ERROR)
             return
+        with guihelper.WXDialogWrapper(ImagePreviewDialog(self, img, self.mainwindow.phoneprofile, self.active_section),
+                                       True) as (dlg, retcode):
+            if retcode==wx.ID_OK:
+                img=dlg.GetResultImage()
+                imgparams=dlg.GetResultParams()
+                # ::TODO:: temporary hack - this should really be an imgparam
+                extension={'BMP': 'bmp', 'JPEG': 'jpg', 'PNG': 'png'}[imgparams['format']]
 
-        img=dlg.GetResultImage()
-        imgparams=dlg.GetResultParams()
-        dlg.Destroy()
-        # ::TODO:: temporary hack - this should really be an imgparam
-        extension={'BMP': 'bmp', 'JPEG': 'jpg', 'PNG': 'png'}[imgparams['format']]
-
-        res=getattr(self, "saveimage_"+imgparams['format'])(img, imgparams)
-        if not res:
-            dlg=wx.MessageDialog(self, "Failed to convert the image in '"+new_file_name+"'",
-                                "Image not converted", style=wx.OK|wx.ICON_ERROR)
-            dlg.ShowModal()
-            dlg.Destroy()
-        self.AddToIndex(name, origin, res, self._data)
+                res=getattr(self, "saveimage_"+imgparams['format'])(img, imgparams)
+                if not res:
+                    guihelper.MessageDialog(self, "Failed to convert the image in '"+new_file_name+"'",
+                                            "Image not converted", style=wx.OK|wx.ICON_ERROR)
+                self.AddToIndex(name, origin, res, self._data)
 
     def OnAddImage(self, img, file, refresh=True, timestamp=None):
         # ::TODO:: if file is None, find next basename in our directory for
         # clipboard99 where 99 is next unused number
         
-        dlg=ImagePreviewDialog(self, img, self.mainwindow.phoneprofile, self.active_section)
-        if dlg.ShowModal()!=wx.ID_OK:
-            dlg.Destroy()
-            return
+        with guihelper.WXDialogWrapper(ImagePreviewDialog(self, img, self.mainwindow.phoneprofile, self.active_section),
+                                       True) as (dlg, retcode):
+            if retcode==wx.ID_OK:
+                img=dlg.GetResultImage()
+                imgparams=dlg.GetResultParams()
+                origin=self.active_section
+                # if we modified the image update the timestamp
+                if not dlg.skip:
+                    timestamp=int(time.time())
 
-        img=dlg.GetResultImage()
-        imgparams=dlg.GetResultParams()
-        origin=self.active_section
-        # if we modified the image update the timestamp
-        if not dlg.skip:
-            timestamp=int(time.time())
+                # ::TODO:: temporary hack - this should really be an imgparam
+                extension={'BMP': 'bmp', 'JPEG': 'jpg', 'PNG': 'png'}[imgparams['format']]
 
-        # ::TODO:: temporary hack - this should really be an imgparam
-        extension={'BMP': 'bmp', 'JPEG': 'jpg', 'PNG': 'png'}[imgparams['format']]
+                # munge name
+                targetfilename=self.get_media_name_from_filename(file, extension)
 
-        # munge name
-        targetfilename=self.get_media_name_from_filename(file, extension)
+                res=getattr(self, "saveimage_"+imgparams['format'])(img, imgparams)
+                if not res:
+                    guihelper.MessageDialog(self, "Failed to convert the image in '"+file+"'",
+                                            "Image not converted", style=wx.OK|wx.ICON_ERROR)
+                    return
 
-        res=getattr(self, "saveimage_"+imgparams['format'])(img, imgparams)
-        if not res:
-            dlg=wx.MessageDialog(self, "Failed to convert the image in '"+file+"'",
-                                "Image not converted", style=wx.OK|wx.ICON_ERROR)
-            dlg.ShowModal()
-            return
-
-        self.AddToIndex(targetfilename, origin, res, self._data, timestamp)
-        if refresh:
-            self.OnRefresh()
+                self.AddToIndex(targetfilename, origin, res, self._data, timestamp)
+                if refresh:
+                    self.OnRefresh()
 
     def saveimage_BMP(self, img, imgparams):
         if img.ComputeHistogram(wx.ImageHistogram())<=236: # quantize only does 236 or less
             img.SetOptionInt(wx.IMAGE_OPTION_BMP_FORMAT, wx.BMP_8BPP)
-        f=common.gettempfilename("bmp")
-        rc = img.SaveFile(f, wx.BITMAP_TYPE_BMP)
-        if rc:
-            data = open(f, 'rb').read()
-        try:    
-            os.remove(f)
-        except: 
-            pass
-        if not rc:
+        with common.usetempfile('bmp') as f:
+            if img.SaveFile(f, wx.BITMAP_TYPE_BMP):
+                return file(f, 'rb').read()
             return False
-        return data
 
     def saveimage_JPEG(self, img, imgparams):
         img.SetOptionInt("quality", 100)        
-        f=common.gettempfilename("jpg")
-        rc = img.SaveFile(f, wx.BITMAP_TYPE_JPEG)
-        if rc:
-            data = open(f, 'rb').read()
-        try:    
-            os.remove(f)
-        except: 
-            pass
-        if not rc:
+        with common.usetempfile('jpg') as f:
+            if img.SaveFile(f, wx.BITMAP_TYPE_JPEG):
+                return file(f, 'rb').read()
             return False
-        return data
 
     def saveimage_PNG(self, img, imgparams):
         # ::TODO:: this is where the file size constraints should be examined
         # and obeyed
-        f=common.gettempfilename("png")
-        rc = img.SaveFile(f, wx.BITMAP_TYPE_PNG)
-        if rc:
-            data = open(f, 'rb').read()
-        try:    
-            os.remove(f)
-        except: 
-            pass
-        if not rc:
+        with common.usetempfile('png') as f:
+            if img.SaveFile(f, wx.BITMAP_TYPE_PNG):
+                return file(f, 'rb').read()
             return False
-        return data
     
     def versionupgrade(self, dict, version):
         """Upgrade old data format read from disk
@@ -652,14 +617,11 @@ def BPFSImageFile(fshandler, location, name=None, img=None, width=-1, height=-1,
     else:
         b=img.ConvertToBitmap()
 
-    f=common.gettempfilename("png")
-    if not b.SaveFile(f, wx.BITMAP_TYPE_PNG):
-        raise Exception, "Saving to png failed"
-
-    data=open(f, "rb").read()
-    os.remove(f)
-
-    return (cStringIO.StringIO(data), location, "image/png", "", wx.DateTime_Now())
+    with common.usetempfile('png') as f:
+        if not b.SaveFile(f, wx.BITMAP_TYPE_PNG):
+            raise Exception, "Saving to png failed"
+        data=open(f, "rb").read()
+        return (cStringIO.StringIO(data), location, "image/png", "", wx.DateTime_Now())
 
     
 class ImageCropSelect(wx.ScrolledWindow):
