@@ -7,14 +7,13 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: widgets.py 3519 2006-08-16 03:05:08Z djpham $
+### $Id: widgets.py 3890 2007-01-11 03:28:43Z djpham $
 
 ### base class for all widgets
 
 import wx
 import re
 
-
 import helpids
 import bphtml
 
@@ -178,6 +177,8 @@ class BitPimWidget:
         pass
 
 class RootWidget(bphtml.HTMLWindow, BitPimWidget):
+    # This page is copied out of the welcome.htm page of the BitPim help
+    # Obviously, it needs to be in sync with the BitPim help.
     welcome_text="""
 <html>
 <head><title>Welcome</title>
@@ -187,25 +188,29 @@ class RootWidget(bphtml.HTMLWindow, BitPimWidget):
 
 <p>Welcome to BitPim.  
 
-<p>If you are new to BitPim, please take the <a href="http://www.bitpim.org/help/tour-master.htm">tour</a>.
+<p>If you are new to BitPim, please take the <a href="tour-master.htm">tour</a>.
 <p>BitPim's homepage is <a href="http://www.bitpim.org" target="bitpimhelpexternallink">www.bitpim.org</a>.
-    The project page is <a href="http://www.sourceforge.net/projects/bitpim" target="bitpimhelpexternallink">www.sourceforge.net/projects/bitpim</a></a>.
+    The project page is <a href="http://www.sourceforge.net/projects/bitpim" target="bitpimhelpexternallink">www.sourceforge.net/projects/bitpim</a>.
 
-<p>You may be interested in <a href="http://www.bitpim.org/help/upgrading.htm">upgrade information</a> or the 
-<a href="http://www.bitpim.org/help/versionhistory.htm">version history</a>.
+<p>You may be interested in <a href="upgrading.htm">upgrade information</a> or the 
+<a href="versionhistory.htm">version history</a>.
 
-<p>If you have any problems or questions please read the <a href="http://www.bitpim.org/help/support.htm">information about support</a>.
-
-<p>BitPim is free software, praise and <a href="http://www.bitpim.org/help/contributing.htm">contributions</a> (e.g. Phones) are always welcome!
+<p>If you have any problems or questions please read the <a href="support.htm">information about support</a>.
 
+<p>Praise and <a href="contributing.htm">contributions</a> are always welcome!
 
 <hr> 
-
-
 </body></html>
 """
 
     def __init__(self, parent, id):
         wx.html.HtmlWindow.__init__(self, parent, id)
         self.SetPage(self.welcome_text)
-
+    def OnLinkClicked(self, link):
+        _ref=link.GetHref()
+        if _ref.startswith('http'):
+            # web link
+            super(RootWidget, self).OnLinkClicked(link)
+        else:
+            # Help topic
+            wx.GetApp().displayhelpid(str(_ref))
